@@ -1,7 +1,8 @@
 import pandas as pd
+
+from ._optional_imports import gp
 from .geometry import GeometryDtype
 from .geoseries import GeoSeries, _MaybeGeoSeries
-from ._optional_imports import gp
 
 
 class _MaybeGeoDataFrame(pd.DataFrame):
@@ -112,6 +113,9 @@ class GeoDataFrame(pd.DataFrame):
             self.geometry.array, parent=self
         )
 
+    def build_sindex(self):
+        self.geometry.build_sindex()
+
     def _ensure_type(self, obj):
         # Override because a GeoDataFrame operation may result in a regular DataFrame,
         # and that's ok
