@@ -2,29 +2,27 @@ import copy
 import json
 import pathlib
 from functools import reduce
+from numbers import Number
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
+import fsspec
 import pandas as pd
-from dask import delayed
-from dask.dataframe import ( # noqa
-    to_parquet as dd_to_parquet,  read_parquet as dd_read_parquet,
-    from_delayed, from_pandas,
-)
-from dask.utils import natural_sort_key
-
-from pandas.io.parquet import (
-    to_parquet as pd_to_parquet,
-)
-
 import pyarrow as pa
+from dask import delayed
+from dask.dataframe import from_delayed, from_pandas
+from dask.dataframe import read_parquet as dd_read_parquet
+from dask.dataframe import to_parquet as dd_to_parquet  # noqa
+from dask.utils import natural_sort_key
+from pandas.io.parquet import to_parquet as pd_to_parquet
 from pyarrow import parquet as pq
-from spatialpandas.io.utils import validate_coerce_filesystem
-from spatialpandas import GeoDataFrame
-from spatialpandas.dask import DaskGeoDataFrame
-from spatialpandas.geometry.base import to_geometry_array
-from spatialpandas.geometry import (
-    PointDtype, MultiPointDtype, RingDtype, LineDtype,
-    MultiLineDtype, PolygonDtype, MultiPolygonDtype, GeometryDtype
-)
+
+from .. import GeoDataFrame
+from ..dask import DaskGeoDataFrame
+from ..geometry import (GeometryDtype, LineDtype, MultiLineDtype,
+                                    MultiPointDtype, MultiPolygonDtype,
+                                    PointDtype, PolygonDtype, RingDtype)
+from ..geometry.base import to_geometry_array
+from ..io.utils import validate_coerce_filesystem
 
 _geometry_dtypes = [
     PointDtype, MultiPointDtype, RingDtype, LineDtype,
@@ -86,19 +84,28 @@ def _get_geometry_columns(pandas_metadata):
 
 
 def to_parquet(
-    df,
+    df: GeoDataFrame,
     fname,
-    compression="snappy",
-    index=None,
-    **kwargs
-):
+    compression: Optional[str] = "snappy",
+    index: Optional[bool] = None,
+    **kwargs,
+) -> None:
     # Standard pandas to_parquet with pyarrow engine
     pd_to_parquet(
-        df, fname, engine="pyarrow", compression=compression, index=index, **kwargs
+        df,
+        fname,
+        engine="pyarrow",
+        compression=compression,
+        index=index,
+        **kwargs,
     )
 
 
-def read_parquet(path, columns=None, filesystem=None):
+def read_parquet(
+    path: str,
+    columns: Optional[Iterable[str]] = None,
+    filesystem: Optional[fsspec.spec.AbstractFileSystem] = None,
+) -> GeoDataFrame:
     filesystem = validate_coerce_filesystem(path, filesystem)
 
     # Load pandas parquet metadata
@@ -136,16 +143,25 @@ def read_parquet(path, columns=None, filesystem=None):
 
 
 def to_parquet_dask(
-        ddf, path, compression="snappy", filesystem=None, storage_options=None, **kwargs
-):
+    ddf: DaskGeoDataFrame,
+    path,
+    compression: Optional[str] = "snappy",
+    filesystem: Optional[fsspec.spec.AbstractFileSystem] = None,
+    storage_options: Optional[Dict[str, Any]] = None,
+    **kwargs,
+) -> None:
     assert isinstance(ddf, DaskGeoDataFrame)
     filesystem = validate_coerce_filesystem(path, filesystem)
     if path and filesystem.isdir(path):
         filesystem.rm(path, recursive=True)
 
     dd_to_parquet(
-        ddf, path, engine="pyarrow", compression=compression,
-        storage_options=storage_options, **kwargs
+        ddf,
+        path,
+        engine="pyarrow",
+        compression=compression,
+        storage_options=storage_options,
+        **kwargs,
     )
 
     # Write partition bounding boxes to the _metadata file
@@ -178,12 +194,19 @@ def to_parquet_dask(
 
 
 def read_parquet_dask(
-        path, columns=None, filesystem=None, load_divisions=False,
-        geometry=None, bounds=None, categories=None,
-):
-    """
-    Read spatialpandas parquet dataset(s) as DaskGeoDataFrame. Datasets are assumed to
-    have been written with the DaskGeoDataFrame.to_parquet or
+    path: str,
+    columns: Optional[Iterable[str]] = None,
+    filesystem: Optional[fsspec.spec.AbstractFileSystem] = None,
+    load_divisions: Optional[bool] = False,
+    geometry: Optional[str] = None,
+    bounds: Optional[Tuple[Number, Number, Number, Number]] = None,
+    categories: Optional[Union[List[str], Dict[str, str]]] = None,
+    build_sindex: Optional[bool] = False,
+) -> DaskGeoDataFrame:
+    """Read spatialpandas parquet dataset(s) as DaskGeoDataFrame.
+
+    Datasets are assumed to have been written with the
+    DaskGeoDataFrame.to_parquet or
     DaskGeoDataFrame.pack_partitions_to_parquet methods.
 
     Args:
@@ -207,6 +230,8 @@ def read_parquet_dask(
             If a list, assumes up to 2**16-1 labels; if a dict, specify the number
             of labels expected; if None, will load categories automatically for
             data written by dask/fastparquet, not otherwise.
+        build_sindex : boolean
+            Whether to build partition level spatial indexes to speed up indexing.
     Returns:
     DaskGeoDataFrame
     """
@@ -233,6 +258,9 @@ def read_parquet_dask(
         categories=categories
     )
 
+    if build_sindex:
+        result = result.build_sindex()
+
     return result
 
 
