@@ -1,5 +1,6 @@
 import pandas.tests.extension.base as eb
 import pytest
+
 from spatialpandas.geometry import LineArray, LineDtype
 
 
@@ -181,6 +182,10 @@ class TestGeometryInterface(eb.BaseInterfaceTests):
     def test_view(self):
         pass
 
+    @pytest.mark.skip(reason="contains not supported")
+    def test_contains(self):
+        pass
+
 
 class TestGeometryMethods(eb.BaseMethodsTests):
     # # AttributeError: 'RaggedArray' object has no attribute 'value_counts'
@@ -231,3 +236,7 @@ class TestGeometryReshaping(eb.BaseReshapingTests):
     @pytest.mark.skip(reason="__setitem__ not supported")
     def test_ravel(self):
         pass
+
+    @pytest.mark.skip(reason="transpose with numpy array elements seems not supported")
+    def test_transpose(self):
+        pass
